@@ -23,17 +23,6 @@ cd $TOP_DIR
 rm .config
 rm *.pyc
 
-##############################################
-# build waf
-cd $DEBIAN_DIR/waf-1.6
-./configure
-cp waf $NS3_DIR
-make distclean
-cd $DEBIAN_DIR/waf-1.5
-./configure
-cp waf $PYBINDGENV_DIR
-make distclean
-
 ################################################
 #clean ns3 dir
 cd $NS3_DIR
@@ -44,6 +33,7 @@ rm -rf ./doc/html
 rm -rf ./doc/latex
 
 make clean -C ./doc/manual
+cp $TOP_DIR/debian/upstream-back/manual-figures/*.png ./doc/manual/figures
 make clean -C ./doc/tutorial
 make clean -C ./doc/models
 
@@ -58,12 +48,10 @@ rm ./different.pcap
 rm -rf ./build
 find . -name '*.pyc' -exec rm {} \;
 find . -name '.waf-*' -exec rm -rf {} \;
-rm waf
 
 cd $PYBINDGENV_DIR
 find . -name '*.pyc' -exec rm {} \;
 find . -name '.waf-*' -exec rm -rf {} \;
-rm waf
 
 cd $NSC_DIR
 ./scons.py -c
